==> usernotification-8.x-1.1.tar.gz: usernotification/src/Form/NotificationSettingsForm.php <==
<?php

namespace Drupal\send_user_notification\Form;

use Drupal\Core\Form\FormBase;
use Drupal\Core\Form\FormStateInterface;

/**
 * Provides a form for performing a 1-click site backup.
 */
class NotificationSettingsForm extends FormBase {

  /**
   * {@inheritdoc}
   */
  public function getFormId() {
    return 'send_user_notification_form';
  }

  /**
   * {@inheritdoc}
   */
  protected function getEditableConfigNames() {
    return [
      'send_user_notification.settings',
    ];
  }

  /**
   * {@inheritdoc}
   */
  public function buildForm(array $form, FormStateInterface $form_state) {
    $form = [];
    $roles = [];
    $config = $this->config('send_user_notification.settings');
    // Theme the form if we want it inline.
    // @FIXME
    $user_roles = user_roles();
    foreach ($user_roles as $key => $role) {
      $roles[$key] = $role->label();
    }

    $form['notification_fieldset'] = [
      '#type' => 'fieldset',
      "#title" => $this->t("Notification Setting"),
      "#collapsible" => FALSE,
      "#collapsed" => FALSE,
      "#tree" => FALSE,
    ];
    $form['notification_fieldset']['subject'] = [
      '#type' => 'textfield',
      "#title" => $this->t('Subject'),
      '#default_value' => !empty($config->get('subject')) ? $config->get('subject') : '',
      '#required' => TRUE,
    ];
    $form['notification_fieldset']['message'] = [
      '#type' => 'textarea',
      "#title" => $this->t('Notification message'),
      '#description' => $this->t('Config to send notification message that will send to user from peopls page.'),
      '#default_value' => !empty($config->get('message')) ? $config->get('message') : '',
      '#required' => TRUE,
      '#rows' => 15,
    ];
    $form['notification_fieldset']['token_tree'] = [
      '#theme' => 'token_tree_link',
      '#token_types' => ['user', 'site'],
      '#show_restricted' => TRUE,
      '#global_types' => FALSE,
      '#weight' => 90,
    ];
    $form['submit'] = [
      '#type' => 'submit',
      '#value' => $this->t('Save configuration'),
      '#weight' => 1,
      '#attributes' => [
        'class' => ['button--primary'],
      ],
    ];

    return $form;
  }

  /**
   * {@inheritdoc}
   */
  public function submitForm(array &$form, FormStateInterface $form_state) {
    $values = $form_state->getValues();
    $config = [];
    $this->configFactory->getEditable('send_user_notification.settings')
      ->set('message', $values['message'])
      ->set('subject', $values['subject'])
      ->save();
  }

}

==> usernotification-8.x-1.4.tar.gz: usernotification/src/Form/NotificationSettingsForm.php <==
<?php

namespace Drupal\send_user_notification\Form;

use Drupal\Core\Form\FormBase;
use Drupal\Core\Form\FormStateInterface;

/**
 * Provides a form for performing a 1-click site backup.
 */
class NotificationSettingsForm extends FormBase {

  /**
   * {@inheritdoc}
   */
  public function getFormId() {
    return 'send_user_notification_form';
  }

  /**
   * {@inheritdoc}
   */
  protected function getEditableConfigNames() {
    return [
      'send_user_notification.settings',
    ];
  }

  /**
   * {@inheritdoc}
   */
  public function buildForm(array $form, FormStateInterface $form_state) {
    $form = [];
    $roles = [];
    $config = $this->config('send_user_notification.settings');
    // Theme the form if we want it inline.
    // @FIXME
    $user_roles = user_roles();
    foreach ($user_roles as $key => $role) {
      $roles[$key] = $role->label();
    }

    $form['notification_fieldset'] = [
      '#type' => 'fieldset',
      "#title" => $this->t("Notification Setting"),
      "#collapsible" => FALSE,
      "#collapsed" => FALSE,
      "#tree" => FALSE,
    ];
    $form['notification_fieldset']['subject'] = [
      '#type' => 'textfield',
      "#title" => $this->t('Subject'),
      '#default_value' => !empty($config->get('subject')) ? $config->get('subject') : '',
      '#required' => TRUE,
    ];
    $form['notification_fieldset']['message'] = [
      '#type' => 'textarea',
      "#title" => $this->t('Notification message'),
      '#description' => $this->t("Configure to send notification message that will send to user from people's page."),
      '#default_value' => !empty($config->get('message')) ? $config->get('message') : '',
      '#required' => TRUE,
      '#rows' => 15,
    ];
    $form['notification_fieldset']['token_tree'] = [
      '#theme' => 'token_tree_link',
      '#token_types' => ['user', 'site'],
      '#show_restricted' => TRUE,
      '#global_types' => FALSE,
      '#weight' => 90,
    ];
    $form['submit'] = [
      '#type' => 'submit',
      '#value' => $this->t('Save configuration'),
      '#weight' => 1,
      '#attributes' => [
        'class' => ['button--primary'],
      ],
    ];

    return $form;
  }

  /**
   * {@inheritdoc}
   */
  public function submitForm(array &$form, FormStateInterface $form_state) {
    $values = $form_state->getValues();
    $config = [];
    $this->configFactory->getEditable('send_user_notification.settings')
      ->set('message', $values['message'])
      ->set('subject', $values['subject'])
      ->save();
  }

}
